ziggy.hdmc.hdfs

Package ziggy :: Package hdmc :: Package hdfs |
[hide private]
[frames] | no frames]

# Source Code for Package ziggy.hdmc.hdfs

     1  '''
     2  Created on Jul 28, 2010
     3  Access functions for files and directories stored in HDFS (Hadoop File System).
     4  @author: dwmclary
     5  '''
     6  __author__ = "D. McClary (dan.mcclary@northwestern.edu)"
     7  __all__ = ["cat", "ls", "rm", "copyToHDFS", "copyFromHDFS"]
     8  from hdfs_access import *
     9